2. Installation — Oncilla 0.1.0 documentation

# 2. Installation

The following dependencies are needed:

- Python 2.6.7 or Python 2.7.3: http://www.python.org/
- PyQt: http://www.riverbankcomputing.co.uk/
- Tidy http://tidy.sourceforge.net/

To install Oncilla from the Python Package Index you can issue this command in a shell:

    pip install Oncilla

or this alternative command:

    easy_install Oncilla

You can also directly install from Github source repository:

    git clone git://github.com/KelSolaar/Oncilla.git
    cd Oncilla
    python setup.py install